@@ -365,18 +365,14 @@ bool CliInterface::runProcess(const QStringList& programNames, const QStringList
     bool ret = (loop.exec(QEventLoop::WaitForMoreEvents | QEventLoop::ExcludeUserInputEvents) == 0);
 #endif
 
-    delete m_process;
-    m_process = 0;
+    Q_ASSERT(!m_process);
 
     return ret;
 }
 
 void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    Q_UNUSED(exitCode)
-    Q_UNUSED(exitStatus)
-
-    kDebug();
+    kDebug() << exitCode << exitStatus;
 
     //if the m_process pointer is gone, then there is nothing to worry
     //about here
@@ -393,6 +389,9 @@ void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus
     //handle all the remaining data in the process
     readStdout(true);
 
+    delete m_process;
+    m_process = 0;
+
     emit progress(1.0);
 
     if (m_operationMode == Add) {
@@ -406,11 +405,9 @@ void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus
 
 void CliInterface::failOperation()
 {
+    // TODO: Would be good to unit test #304764/#304178.
     kDebug();
-
     doKill();
-
-    emit finished(false);
 }
 
 void CliInterface::readStdout(bool handleAll)
